program multitaper

! 
! The program calls the mtspec subroutine to get the
! spectrum, as in Thomson (1982).  
!

!**********************************************************************

   use spectra 
   use plot

   implicit none

!  time series

   integer :: npts, nskip
   real(4), dimension(:), allocatable :: x, t
   
!  spectra and frequency

   integer :: nf

   real(4), dimension(:), allocatable :: spec, freq

   real(4), dimension(:,:), allocatable :: err

!  Spectral parameters

   integer :: kspec

   real(4) :: tbp, dt
  
!  Others

   integer :: ios
   
   integer :: i, k

   character (len = 100) :: filename

!********************************************************************

!  Set up data vector

   write(6,'(a)') 'Input the data filename '
   read(5,'(a)') filename

   write(6,'(a)')' input the # of data points to skip and read '
   read(5,*) nskip, npts

   write(6,'(a)') 'Input the time-bandwidth product '
   read(5,*) tbp

   write(6,'(a)')' input the # of tapers to use '
   read(5,*) kspec

   write(6,'(a)')' input dt '
   read(5,*) dt

   npts = npts-nskip

   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   nf = 1 + npts/2

   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf

!
!  Allocate memory
!

   allocate(x(npts))
   allocate(t(npts))
   allocate(freq(nf))
   allocate(spec(nf))
   allocate(err(nf,2))


!
!  Define time axis
!

   do i = 1,npts
      t(i) = real(i)*dt
   enddo

   open (11, file=filename, status='old')

   do k = 1, nskip
      read(11,*, iostat=ios) 
      if (ios<0) then
         ! End of file encountered
         exit
      endif
   enddo
   do k = 1,npts
      read(11,*,iostat=ios) x(k)
      if (ios<0) then
         exit
      endif
   enddo

   close(11)

!
!  Get the spectrum estimate
!

   call mtspec(npts,dt,x,tbp,kspec,nf,freq,spec,err=err)

   call gplot(freq,spec,'hold',logxy='loglog')
   call gplot(freq,err(:,1),'hold')
   call gplot(freq,err(:,2))



!   open(12,file='jk_spec.dat')
!   write(6,'(4a16)') 'freq', 'spec', '-95%', '+95%'
!   do i = 1,nf
!      write(12,'(4E16.7)') freq(i), spec(i), err(i,1), err(i,2)
!   enddo
!
!   close(12)
   
end program multitaper

