subroutine df_spec ( npts,dt,x,tbp,kspec,nf,                   &
                     filename )  
            

!
!  Construct the dual-frequency spectrum from the yk's and the 
!  weights of the usual multitaper spectrum estimation. 
!  The dual-frequency spectrum is saved in a file, needed for 
!  long time series where computer memory breaks down.
!  

!********************************************************************

   use spectra

   implicit none

!  Inputs

   integer, intent(in) :: npts, kspec, nf

   real(4), intent(in) :: dt, tbp

   real(4), dimension(npts), intent(in) :: x

   character (len=100), intent(in) :: filename

!  spectra and frequency

   real(4), dimension(nf) :: spec

   real(4), dimension(nf,kspec) :: wt 

   complex(4), dimension(npts,kspec) :: yk

!  spectra and frequency

   real(4), dimension(nf) :: freq

!  Dual freq matrices

   complex(4), dimension(nf,kspec)     :: dyk 
   real(4), dimension(nf)              :: dk 
   
   real(4), dimension(nf)    :: df_cohe, df_phase
 
   complex(4), dimension(nf) :: df_spectra

!  Others

   integer :: i, j

   character (len = 100) :: fmt, file1, file2

   real(4), parameter :: pi = 3.14159265358979 

!********************************************************************

   write(6,'(a,2i5)') 'Data points and frequency points', npts, nf

!
!  Get the spectrum estimate
!

   call mtspec ( npts,dt,x,tbp,kspec,nf,freq,          &
                 spec,yk,wt)
      
!
!  Create the spectra (cannot use spec output, normalized different)
!

   spec = sum( wt**2 * (abs(yk(1:nf,:)))**2 , dim=2)/    &
                     sum((wt**2),dim=2)

   dk = sqrt( sum (wt(:,:)**2, dim=2) )

   dyk(:,:) = wt(:,:) * yk(1:nf,:)

   file1 = trim(filename) // '_df.dat'
   file2 = trim(filename) // '_ph.dat'
   
   open(12,file=file1,form='formatted')
   open(13,file=file2,form='formatted')

   write(fmt,'(i12)') nf
   fmt = '(' // trim(adjustl(fmt)) // 'E16.7)'

   do i=1,nf

      if (mod(i,1000) == 0) then
         write(6,'(a,i5,a,i5)') 'Loop ',i , ' of ', nf 
      endif

   ! df_spectrum and coherence
   
      do j = 1,nf
         
         df_spectra(j) = sum ( dyk(i,:) * conjg(dyk(j,:)) )   &
                               / (dk(i)*dk(j))

         df_cohe(j) = (abs(df_spectra(j)))**2 / (spec(i)*spec(j))

         df_phase(j) = atan2( aimag(df_spectra(j)), real(df_spectra(j)) ) 

      enddo
      
      write(12,fmt) ( real(df_cohe(:)) )
      write(13,fmt) ( real(df_phase(:)))

   enddo


   close(12)
   close(13)

end subroutine df_spec








