subroutine fft_2d(data,npts,nfft)

!
!  Modified
!	German Prieto
!	November 2004
!
!  The discrete fourier tranform of a complex data set of of Fourier 
!  coefficients of size npts, with nfft vectors in columns. The FFT 
!  is taken over the columns. 
!
!  Discussion:
!
! 	Note here that we are working with double precision, to keep 
! 	the notation from the multitaper code accordingly. 
!	This FFT does not seem to have the limitations of other 
!	codes, in the sense that it is capable of computing iFFTs
!      	for any size of the data. 
!
!  Input/Output 	
!
!	data	the complex data to be forward transformed, data(npts,nfft)
!
!  Input
!
!	npts	the length of the fourier coefficient data
!       nfft	the number of columns to the FFT's from.
!
!  calls cffti, cfftf
!

!**********************************************************************

   implicit none

   integer 	       :: i
   integer, intent(in) :: npts, nfft
   
   real(8), dimension(4*npts+15) :: wsave

   complex(8), intent(in out), dimension(npts,nfft) :: data
   
!**********************************************************************

   if (nfft>4000 .and. npts>4000) then
      write(6,'(a)') 'It may take a while'
   endif

   call cffti(npts, wsave)

   do i = 1,nfft
      call cfftf(npts, data(:,i), wsave)
   enddo
   
   return

end subroutine fft_2d




