double precision function r1mach(i)

!
!  Modified
!	German Prieto
!	November 2004
!
!  double precision function r1mach
!
!  
!  keywords  machine constants
!  author  fox p.a.,.hall a.d., schryer n.l. (bell labs)
!  
!  purpose
! 	returns single precision machine dependent constants
!
!  description
!
!     r1mach can be used to obtain machine-dependent parameters
!     for the local machine environment.  it is a function
!     subroutine with one (input) argument, and can be called
!     as follows, for example
!
!          a = r1mach(i)
!
!     where i=1,...,5.  the (output) value of a above is
!     determined by the (input) value of i.  the results for
!     various values of i are discussed below.
!
!  single-precision machine constants
!  r1mach(1) = b**(emin-1), the smallest positive magnitude.
!  r1mach(2) = b**emax*(1 - b**(-t)), the largest magnitude.
!  r1mach(3) = b**(-t), the smallest relative spacing.
!  r1mach(4) = b**(1-t), the largest relative spacing.
!  r1mach(5) = log10(b)
!
!  to alter this function for a particular environment,
!  the desired set of data statements should be activated by
!  removing the ! from column 1.
!
!  where possible, octal or hexadecimal constants have been used
!  to specify the constants exactly which has in some cases
!  required the use of equivalent integer arrays.
!
!  references
!  
!	fox p.a., hall a.d., schryer n.l.,*framework for a portable library*,
!  	acm transaction on mathematical software, vol. 4, no. 2,
!  	june 1978, pp. 177-188.
!
!
!     integer small(2)
!     integer large(2)
!     integer right(2)
!     integer diver(2)
!     integer log10(2)
!
!      data rmach(1) /5.8774716e-39/
!      data rmach(2) /1.7014116e38/
!      data rmach(3) /2.3841857e-7/
!      data rmach(4) /4.7683714e-7/
!      data rmach(5) /0.301030/
!

!**********************************************************************

   implicit none
  
   integer :: i

   real(8) :: rmach(5)

!**********************************************************************

   rmach(1) = 2.9387358d-39
   rmach(2) = 1.7014116d38
   rmach(3) = 1.1920928d-7
   rmach(4) = 2.3841857d-7
   rmach(5) = 0.301030d0

   r1mach = rmach(i)
      
   return

end function r1mach

