program mw_test

! 
! The program calls the mtspec subroutine to get the
! spectrum, as in Thomson (1982).  
!

!**********************************************************************

   use spectra 

   implicit none

!  time series

   integer :: npts
   real(8), dimension(:), allocatable :: x, t
   
!  spectra and frequency

   integer :: nf

   real(8), dimension(:), allocatable :: spec, freq, sbar

   real(8), dimension(:,:), allocatable :: err
  
!  Spectral parameters

   integer :: kspec

   real(8) :: tbp, dt
   
!  Others

   integer :: ios
   
   integer :: i, k

   character (len = 100) :: filename

!********************************************************************

   write(6,'(a)') 'The number of tapers to get '
   read(5,*) kspec

   write(6,'(a)') 'The time bandwidth product '
   read(5,*) tbp

   write(6,'(a)') 'The time series length (361 points)'

   npts = 361

   dt = 5.0d0 

   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   nf = 1 + npts/2

   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf

!
!  Allocate memory
!

   allocate(x(npts))
   allocate(t(npts))
   allocate(freq(nf))
   allocate(spec(nf))
   allocate(err(nf,2))
   allocate(sbar(nf))
  
!
!  Define time axis
!

   do i = 1,npts
      t(i) = dble(i)*dt
   enddo

   filename = 'th_data.dat'

   open (11, file=filename, status='old')

   do k = 1, npts
      read(11,*, iostat=ios) x(k)
      if (ios<0) then
         ! End of file encountered
         exit
      endif
   enddo

   close(11)

!
!  Get the spectrum estimate
!

   call mtspec(npts,dt,x,tbp,kspec,nf,freq,spec,err=err,sbar=sbar)

!
!  Save data and spectrum
!

   open(12,file='mw_ts.dat')
   write(6,'(2a16)') 'time', 'Signal'
   do i = 1,npts
      write(12,'(2E16.7)') t(i), x(i)
   enddo

   close(12)

   open(12,file='mw_spec.dat')
   write(6,'(5a16)') 'freq', 'spec', '-95%', '+95%', 'mean'
   do i = 1,nf
      write(12,'(5E16.7)') freq(i), spec(i), err(i,1), err(i,2), sbar(i)
   enddo

   close(12)

   
end program mw_test

