program mx_test		

! 
! The program calls the mtspec subroutine to get the
! spectrum, as in Thomson (1982), loading the data
! saved in Matlab in a standardized format, as a matrix.
! 
! INPUT
!       data(npts,nseries)
!
! OUTPUT
!	freq(npts/2+1) spec(npts/2+1,nseries) 
!       5%(npts/2+1,nseries)  95%(npts/2+1,nseries)
!

!**********************************************************************

   use spectra 

   implicit none

!  time series

   real(4), dimension(1201,2) :: xmat 
   integer :: npts,ntimes
   
!  spectra and frequency

   integer :: nf

   real(4), dimension(601,2) :: spec
   real(4), dimension(601)   :: freq

   real(4), dimension(601,2,2) :: err

!  Spectral parameters

   integer :: kspec

   real(4) :: tbp, dt
  
!  Others

   integer :: ios
   
   integer :: i, k

   character (len = 100) :: fmt, filename

!********************************************************************

   filename = 'matrix_test.dat'
   open (11, file=filename, status='old')

   npts = 1201
   ntimes=2
   kspec = 8
   dt = 0.01
   tbp = 5.

   print *, npts
   print *, kspec
   
   if (npts <= 1) then
      write(6,'(a)') '>>> Too few terms in the series to estimate a spectrum'
      stop
   endif

      
   nf = 1 + npts/2

   write(6,'(a,2i10)') 'Number of points in time series and fft ', npts, nf


   do i = 1, npts
         read(11,*, iostat=ios) xmat(i,:)
         if (ios<0) then
            ! End of file encountered
            exit
         endif
   enddo
   
   close(11)

   print *, xmat(1:5,1)

   print *, xmat(1:5,2)

!
!  Get the spectrum estimate
!

   call mtspec(ntimes,npts,dt,xmat,tbp,kspec,nf,freq,spec,err)

!      call gplot(freq,spec,'hold',logxy='loglog')
!      call gplot(freq,err(:,1),'hold')
!      call gplot(freq,err(:,2))

      
   open(12,file='mx_spec.dat')
   write(6,'(2a16)') 'spec', 'spec'
   do i = 1,nf
      write(12,'(6E16.7)') spec(i,1), spec(i,2), err(i,1,1), err(i,2,1),    &
                                                 err(i,1,2), err(i,2,2)
   enddo

   close(12)

end program mx_test


